	
#ifndef _WMISMB_H_
#define _WMISMB_H_

#pragma pack(push,1)

//
// Reference: SMBIOS spec on http://www.dmtf.org/standards/bios.php
//
		
typedef struct _SMBIOS_DATA
{
    UCHAR       bUsed20CallingMethod;
    UCHAR       ucSmbiosMajorVersion;
    UCHAR       ucSmbiosMinorVersion;
    UCHAR       ucDmiRevision;
    ULONG       uSize;
    UCHAR       ucSMBiosData[1];

} SMBIOS_DATA,   *PSMBIOS_DATA;

//
// Only dump Type 0 and Type 1 as  example
//

//==============================================================================
// 3.2.1 BIOS Information (Type 0)

typedef struct _tagBIOSINFO
{
    BYTE    Type;                            // 0    BIOS Information Indicator
    BYTE    Length;                            // Varies, 12h + number of BIOS Characteristics Extension Bytes
    WORD    Handle;
    BYTE    Vendor;
    BYTE    BIOS_Version;
    WORD    BIOS_Starting_Address_Segment;
    BYTE    BIOS_Release_Date;
    BYTE    BIOS_ROM_Size;
    ULONG64 BIOS_Characteristics;
    BYTE    BIOS_Characteristics_Ext[1];    // usually, one could be more.  see note on length.

} BIOSINFO, *PBIOSINFO;


// 3.2.1.1 BIOS Characteristics
//QWORD Bit Position    Meaning if Set

#define TYPE0_RESERVED00                    0x0000000000000001
#define TYPE0_RESERVED01                    0x0000000000000002
#define UNKNOWN                             0x0000000000000004
#define BIOS_CHARACTERISTICS_NOT_SUPPORTED  0x0000000000000008
#define ISA_SUPPORT                         0x0000000000000010
#define MCA_SUPPORT                         0x0000000000000020
#define EISA_SUPPORT                        0x0000000000000040
#define PCI_SUPPORT                         0x0000000000000080
#define PC_CARD_SUPPORT                     0x0000000000000100
#define PNP_SUPPORT                         0x0000000000000200
#define APM_SUPPORT                         0x0000000000000400
#define BIOS_IS_FLASH_UPGRADEABLE           0x0000000000000800
#define BIOS_SHADOWING                      0x0000000000001000
#define VL_VESA                             0x0000000000002000
#define ESCD_SUPPORT                        0x0000000000004000
#define BOOT_FROM_CD                        0x0000000000008000
#define SELECTABLE_BOOT                     0x0000000000010000
#define BIOS_ROM_SOCKETED                   0x0000000000020000
#define BOOT_FROM_PC_CARD                   0x0000000000040000
#define EDD_SPEC_SUPPORTED                  0x0000000000080000
#define INT_13H_JPN_FLOPPY_NEC_9800_1_2MB   0x0000000000100000
#define INT_13H_JPN_FLOPPY_TOSHIBA_1_2MB    0x0000000000200000
#define INT_13H_5_25_360KB_FLOPPY           0x0000000000400000
#define INT_13H_5_25_1_2MB_FLOPPY           0x0000000000800000
#define INT_13H_3_5_720KB_FLOPPY            0x0000000001000000
#define INT_13H_3_5_2_88MB_FLOPPY           0x0000000002000000
#define INT_5H_PRINT_SCREEN                 0x0000000004000000
#define INT_9H_8042_KEYBOARD                0x0000000008000000
#define INT_14H_SERIAL                      0x0000000010000000
#define INT_17H_PRINTER                     0x0000000020000000
#define INT_10H_CGA_MONO_VIDEO              0x0000000040000000
#define NEC_PC_98                           0x0000000080000000
#define BIOS_VENDOR_RESERVED                0x0000ffff00000000
#define SYSTEM_VENDOR_RESERVED              0xffff000000000000

// 3.2.1.2.1 BIOS Characteristics Extension Byte 1

#define ACPI_SUPPORT                    0x01
#define USB_LEGACY_SUPPORT              0x02
#define AGP_SUPPORT                     0x04
#define I2O_BOOT_SUPPORT                0x08
#define LS_120_BOOT_SUPPORT             0x10
#define ATAPI_ZIP_DRIVE_BOOT_SUPPORT    0x20
#define IEEE1394_BOOT_SUPPORT           0x40
#define SMART_BATTERY_SUPPORT           0x80

// 3.2.1.2.2 BIOS Characteristics Extension Byte 2

#define BIOS_BOOT_SPECIFICATION         0x01
#define FUNCTION_KEY_NETWORK_BOOT       0x02
#define BIOS_CHA_2_RESERVED             0xFC

//==============================================================================
// 3.2.2 System Information (Type 1)

typedef struct tagSYSTEMINFO
{
    BYTE    Type;         // 1    Component ID Information  Indicator
    BYTE    Length;        // 08h or 19h    Length dependent on version supported
    WORD    Handle;
    BYTE    Manufacturer;
    BYTE    Product_Name;
    BYTE    Version;
    BYTE    Serial_Number;
    // Ver 2.1+ beyond here
    BYTE    UUID[16];
    BYTE    Wakeup_Type;

} SYSTEMINFO, *PSYSTEMINFO;

// 3.2.2.1 System - Wake-up Type

#define WU_RESERVED             0x00
#define WU_OTHER                0x01
#define WU_UNKNOWN              0x02
#define WU_APM_TIMER            0x03
#define WU_MODEM_RING           0x04
#define WU_LAN_REMOTE           0x05
#define WU_POWER_SWITCH         0x06
#define WU_PCI_PME              0x07
#define WU_AC_POWER_RESTORED	0x08

typedef struct _DUMPFILE_HEAD
{
    UCHAR       ucSmbiosMajorVersion;
    UCHAR       ucSmbiosMinorVersion;
    UCHAR       ucDmiRevision;

} DUMPFILE_HEAD, *PDUMPFILE_HEAD;


void
DisplaySMBIOSTable (
    PSMBIOS_DATA    pSmbiosData
	);
/*++

Purpose: 

  DisplaySMBIOSTable only diplay type 0 and type 1 as example. Interested users
  could parse the entire table following SMBIOS spec on 
  http://www.dmtf.org/standards/bios.php.

--*/

LPBYTE
FindSmbiosStructure (
    PSMBIOS_DATA    pSmbiosData,
    ULONG           uType,
    PULONG          pLength
    );

void
DumpSMBIOSTable (
    LPSTR           pszOutFile,
    PSMBIOS_DATA    pSmbiosData
    );

void
Usage(
    void
	);

int
ParseParameters (
    IN  int		argc,
	IN  char*	argv[],
	OUT	char**	ppstrDumpFile
	);

#define MAXPATHLENGTH	256
char	g_strDumpFilePath [MAXPATHLENGTH]; 
char*	g_pstrDumpFilePath	= NULL;

#pragma pack(pop)

#endif    // #define  _WMISMB_H_ 
